@@ -62,6 +62,7 @@
 #include "encoder_table.h"
 #include "post.h"
 #include "reqs_list.h"
+#include "header-protected.h"
 
 
 typedef enum {
@@ -79,6 +80,7 @@ typedef enum {
 	phase_lingering
 } cherokee_connection_phase_t;
 
+
 struct cherokee_connection {
 	struct list_head              list_entry;
 
@@ -94,13 +96,9 @@ struct cherokee_connection {
 	
 	/* Socket stuff
 	 */
-	cherokee_socket_t            *socket;
+	cherokee_socket_t             socket;
 	int                           tcp_cork;
-	int                           extra_polling_fd;
 		
-	cherokee_buffer_t             query_string;	
-	cherokee_table_t             *arguments;
-
 	cherokee_logger_t            *logger_ref;
 	int                           log_at_end;
 	
@@ -121,7 +119,7 @@ struct cherokee_connection {
 	
 	/* Headers
 	 */
-	cherokee_header_t            *header;
+	cherokee_header_t             header;
 
 	/* Encoders
 	 */
@@ -136,8 +134,12 @@ struct cherokee_connection {
 	cherokee_buffer_t             request;             /* /dir/file */
 	cherokee_buffer_t             pathinfo;            /* /param1 */
 	cherokee_buffer_t             userdir;             /* 'alo' in http://www.alobbs.com/~alo/thing */
+	cherokee_buffer_t             query_string;	
+	cherokee_table_t             *arguments;
+
 	cherokee_buffer_t             host;
 	cherokee_buffer_t             effective_directory;
+	cherokee_buffer_t             redirect;
 
 	/* Espace versions
 	 */
@@ -163,11 +165,13 @@ struct cherokee_connection {
 	/* Post info
 	 */
 	cherokee_post_t               post;
-
-	cherokee_buffer_t             redirect;
-	
-	time_t                        timeout;
 	uint32_t                      keepalive;
+	time_t                        timeout;
+
+	/* Polling
+	 */
+	int                           polling_fd;
+	cherokee_boolean_t            polling_multiple;
 
 	off_t                         range_start;
 	off_t                         range_end;
@@ -206,16 +210,16 @@ ret_t cherokee_connection_recv                   (cherokee_connection_t *cnt, ch
 
 /* Internal
  */
-ret_t cherokee_connection_get_dir_entry          (cherokee_connection_t *cnt, cherokee_dirs_table_t *dirs, cherokee_config_entry_t *plugin_entry);
-ret_t cherokee_connection_get_ext_entry          (cherokee_connection_t *cnt, cherokee_exts_table_t *exts, cherokee_config_entry_t *plugin_entry);
-ret_t cherokee_connection_get_req_entry          (cherokee_connection_t *cnt, cherokee_reqs_list_t  *reqs, cherokee_config_entry_t *plugin_entry);
+ret_t cherokee_connection_get_dir_entry          (cherokee_connection_t *cnt, cherokee_dirs_table_t *dirs, cherokee_config_entry_t *config_entry);
+ret_t cherokee_connection_get_ext_entry          (cherokee_connection_t *cnt, cherokee_exts_table_t *exts, cherokee_config_entry_t *config_entry);
+ret_t cherokee_connection_get_req_entry          (cherokee_connection_t *cnt, cherokee_reqs_list_t  *reqs, cherokee_config_entry_t *config_entry);
 
-ret_t cherokee_connection_create_handler         (cherokee_connection_t *cnt, cherokee_config_entry_t *plugin_entry);
+ret_t cherokee_connection_create_handler         (cherokee_connection_t *cnt, cherokee_config_entry_t *config_entry);
 ret_t cherokee_connection_setup_error_handler    (cherokee_connection_t *cnt);
-ret_t cherokee_connection_check_authentication   (cherokee_connection_t *cnt, cherokee_config_entry_t *plugin_entry);
-ret_t cherokee_connection_check_ip_validation    (cherokee_connection_t *cnt, cherokee_config_entry_t *plugin_entry);
-ret_t cherokee_connection_check_only_secure      (cherokee_connection_t *cnt, cherokee_config_entry_t *plugin_entry);
-ret_t cherokee_connection_check_http_method      (cherokee_connection_t *cnt, cherokee_config_entry_t *plugin_entry);
+ret_t cherokee_connection_check_authentication   (cherokee_connection_t *cnt, cherokee_config_entry_t *config_entry);
+ret_t cherokee_connection_check_ip_validation    (cherokee_connection_t *cnt, cherokee_config_entry_t *config_entry);
+ret_t cherokee_connection_check_only_secure      (cherokee_connection_t *cnt, cherokee_config_entry_t *config_entry);
+ret_t cherokee_connection_check_http_method      (cherokee_connection_t *cnt, cherokee_config_entry_t *config_entry);
 
 /* Iteration
  */
@@ -231,6 +235,7 @@ ret_t cherokee_connection_parse_header           (cherokee_connection_t *cnt, ch
 int   cherokee_connection_is_userdir             (cherokee_connection_t *cnt);
 ret_t cherokee_connection_build_local_directory  (cherokee_connection_t *cnt, cherokee_virtual_server_t *vsrv, cherokee_config_entry_t *entry);
 ret_t cherokee_connection_build_local_directory_userdir (cherokee_connection_t *cnt, cherokee_virtual_server_t *vsrv, cherokee_config_entry_t *entry);
+ret_t cherokee_connection_clean_for_respin       (cherokee_connection_t *cnt);
 
 /* Log
  */
