@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001, 2002, 2003, 2004, 2005 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2006 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -27,6 +27,8 @@
 #include "table.h"
 #include "table-protected.h"
 
+#define ENTRIES "exts"
+
 
 struct cherokee_exts_table {
 	cherokee_table_t table;
@@ -70,6 +72,8 @@ cherokee_exts_table_get (cherokee_exts_table_t *et, cherokee_buffer_t *requested
 
 	ret = cherokee_table_get (&et->table, dot+1, (void **)&entry);
 	if (ret != ret_ok) return ret;
+
+	TRACE (ENTRIES, "Match with \"%s\"\n", dot+1);
 	
 	cherokee_config_entry_complete (plugin_entry, entry, false);
 	return ret_ok;
