@@ -31,11 +31,7 @@
 #include "module_loader.h"
 
 
-cherokee_module_info_handler_t MODULE_INFO(error_redir) = {
-	.module.type     = cherokee_handler,                 /* type         */
-	.module.new_func = cherokee_handler_error_redir_new, /* new func     */
-	.valid_methods   = http_all_methods                  /* http methods */
-};
+HANDLER_MODULE_INFO_INIT_EASY (error_redir, http_all_methods);
 
 
 ret_t 
