@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001, 2002, 2003, 2004, 2005 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2006 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -81,7 +81,7 @@ cherokee_resolv_cache_get_default (cherokee_resolv_cache_t **resolv)
 		return ret_ok;
 	}
 	
-	*resolv = malloc (sizeof(cherokee_resolv_cache_t));
+	*resolv = (cherokee_resolv_cache_t *) malloc (sizeof(cherokee_resolv_cache_t));
 	return cherokee_resolv_cache_init (*resolv);
 }
 
