@@ -171,7 +171,6 @@ cherokee_server_new  (cherokee_server_t **srv)
 
 	CHEROKEE_RWLOCK_WRITER (&n->bogo_now_mutex);
 	cherokee_buffer_new (&n->bogo_now_string);
-	cherokee_buffer_ensure_size (n->bogo_now_string, 100);	
 	CHEROKEE_RWLOCK_UNLOCK (&n->bogo_now_mutex);
 
 	/* Time managing hack
@@ -1095,40 +1094,37 @@ update_bogo_now (cherokee_server_t *srv)
 	time_t       newtime;
 	static long *this_timezone = NULL;
 
+	/* Read the time
+	 */
+	newtime = time (NULL);
+	if (srv->bogo_now >= newtime) 
+		return;
+
+	/* Update the internal variable
+	 */
 	CHEROKEE_RWLOCK_WRITER (&srv->bogo_now_mutex);      /* 1.- lock as writer */
 
-	newtime = time (NULL);
-	if (srv->bogo_now != newtime) {
-		time_t prevtime = srv->bogo_now;
-
-		srv->bogo_now  = newtime;
-		cherokee_localtime (&newtime, &srv->bogo_now_tm);
-
-		/* Update time string if needed
-		 */
-		if (prevtime < newtime) {
-			int z;
-
-			cherokee_buffer_clean (srv->bogo_now_string);
-
-			if (this_timezone == NULL) 
-				this_timezone = cherokee_get_timezone_ref();
-			z = - (*this_timezone / 60);
-
-			cherokee_buffer_add_va (srv->bogo_now_string,
-					"%s, %02d %s %d %02d:%02d:%02d GMT%c%d",
-					cherokee_weekdays[srv->bogo_now_tm.tm_wday], 
-					srv->bogo_now_tm.tm_mday,
-					cherokee_months[srv->bogo_now_tm.tm_mon], 
-					srv->bogo_now_tm.tm_year + 1900,
-					srv->bogo_now_tm.tm_hour,
-					srv->bogo_now_tm.tm_min,
-					srv->bogo_now_tm.tm_sec,
-					(z < 0) ? '-' : '+',
-					(z / 60));
-		}
-	}
+	srv->bogo_now = newtime;
+	cherokee_localtime (&newtime, &srv->bogo_now_tm);
 
+	/* Update time string 
+	 */
+	if (unlikely (this_timezone == NULL))
+		this_timezone = cherokee_get_timezone_ref();
+		
+	cherokee_buffer_clean  (srv->bogo_now_string);
+	cherokee_buffer_add_va (srv->bogo_now_string,
+				"%s, %02d %s %d %02d:%02d:%02d GMT%c%d",
+				cherokee_weekdays[srv->bogo_now_tm.tm_wday], 
+				srv->bogo_now_tm.tm_mday,
+				cherokee_months[srv->bogo_now_tm.tm_mon], 
+				srv->bogo_now_tm.tm_year + 1900,
+				srv->bogo_now_tm.tm_hour,
+				srv->bogo_now_tm.tm_min,
+				srv->bogo_now_tm.tm_sec,
+				srv->bogo_now_tm.tm_gmtoff < 0 ? '-' : '+',
+				abs(srv->bogo_now_tm.tm_gmtoff / 3600));
+	
 	CHEROKEE_RWLOCK_UNLOCK (&srv->bogo_now_mutex);      /* 2.- release */
 }
 
