@@ -3,6 +3,7 @@
 /* Cherokee
  *
  * Authors:
+ *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *      Gisle Vanem <giva@bgnett.no>
  *
  * Copyright (C) 2001-2006 Alvaro Lopez Ortega
@@ -59,13 +60,25 @@ static WSADATA wsa_data;
 /*
  * Constructor/DllMain
  */
-static _ctor void win_init (void)
+static void 
+exit_function (void)
 {
-  if (WSAStartup (MAKEWORD(1,1), &wsa_data) != 0)
-  {
+   WSACleanup();
+}
+
+void 
+init_win32 (void)
+{
+  int re;
+
+  re = WSAStartup (MAKEWORD(1,1), &wsa_data);
+  if (re != 0) {
     PRINT_ERROR ("WSAStartup failed; %s\n", win_strerror(GetLastError()));
     exit (-1);
   }
+
+  atexit (exit_function);
+
   first_sock_num = socket (AF_INET, SOCK_STREAM, 0);
   assert (first_sock_num > 0);
   closesocket (first_sock_num);
@@ -75,7 +88,7 @@ static _ctor void win_init (void)
 BOOL APIENTRY DllMain (HANDLE dll_handle, DWORD reason, LPVOID reserved)
 {
   if (reason == DLL_PROCESS_ATTACH)
-     win_init();
+	init_win32();
 
   (void) dll_handle;
   (void) reserved;
@@ -518,13 +531,18 @@ void *win_dlopen (const char *dll_name, int flags)
 {
   void *rc;
 
-  last_func = "win_dlopen";
-  rc = (void*) LoadLibrary (dll_name);
-  if (rc)
-       last_error = 0;
-  else last_error = GetLastError();
+  last_error = 0;
+  last_func  = "win_dlopen";
 
- TRACE ("dlfcn", "%s, %s\n", dll_name, rc ? "ok" : "fail");
+  if (dll_name == NULL)
+		rc = (void *) GetModuleHandle (NULL);
+  else 
+		rc = (void *) LoadLibrary (dll_name);
+  
+  if (rc == NULL)
+		last_error = GetLastError();
+
+  TRACE ("dlfcn", "%s, %s\n", dll_name, rc ? "ok" : "fail");
 
   (void) flags;
   return (rc);
@@ -537,15 +555,18 @@ void *win_dlsym (const void *dll_handle, const char *func_name)
 
   if (!hnd)
      hnd = GetModuleHandle (NULL);
-  last_func = "win_dlsym";
+
+  last_error = 0;
+  last_func  = "win_dlsym";
+
   rc = (void*) GetProcAddress (hnd, func_name);
-  if (rc)
-       last_error = 0;
-  else last_error = GetLastError();
+  if (rc == NULL)
+       last_error = GetLastError();
 
-  TRACE ("dlfcn", "%s, %s\n", func_name, rc ? "ok" : "fail");
+  TRACE ("dlfcn", "func=%s result=%s error=%d\n",
+	    func_name, rc ? "ok" : "fail", last_error);  
 
-  return (rc);
+  return rc;
 }
 
 int win_dlclose (const void *dll_handle)
@@ -926,3 +947,34 @@ static const char *inet_ntop6 (const u_char *src, char *dst, size_t size)
 }
 #endif  /* HAVE_IPV6 */
 
+
+unsigned int
+sleep (unsigned int seconds)
+{
+	   Sleep (seconds * 1000);
+	   return 0;
+}
+
+int 
+cherokee_win32_stat (const char *path, struct stat *buf)
+{
+	   int e = 0;
+	   int len;
+	   int re;
+	   char *p = (char *)path;
+
+	   len = strlen(p);
+	   while ((p[len-(e+1)] == '/') &&  (len - e > 3))
+	   {
+			 p[len-(e+1)] = '\0';
+			 e++;
+	   }
+
+	   re = stat ((const char *)p, buf);
+
+	   for (e-=1; e>0; e--) {
+			 p[len-(e+1)] = '/';
+	   }
+
+	   return re;
+}
