@@ -3,18 +3,18 @@ import string
 from base import *
 from util import *
 
-MAGIC = str_random(10*1024)
+LENGTH = 50*1024
 
 
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self)
-        self.name = "10k random"
+        self.name = "50k random"
 
-        self.request          = "GET /10k HTTP/1.0\r\n"
+        self.request          = "GET /50k HTTP/1.0\r\n"
         self.expected_error   = 200
-        self.expected_content = MAGIC
 
     def Prepare (self, www):
-        self.WriteFile (www, "10k", 0444, MAGIC)
+        f = self.WriteFile (www, "50k", 0444, str_random (LENGTH))
+        self.expected_content = "file:" + f
 
