@@ -22,7 +22,7 @@ class Test (TestBase):
 
         forbidden = self.WriteTemp (srandom[OFFSET:])
 
-        self.expected_content  = [srandom[:OFFSET], "Content-Length: %d" % (OFFSET)]
+        self.expected_content  = [srandom[:OFFSET], "Content-Length: %d" % (OFFSET +1)]
         self.forbidden_content = "file:" + forbidden
 
 
